import RPi.GPIO as GPIO

OutputPins = [2, 3]

def initialize():
	# Configures how we are describing our pin numbering
	GPIO.setmode(GPIO.BCM)
	# Desable warnings
	GPIO.setwarnings(False)
	# Set the GPIO pins that are required
	
	for i in OutputPins:
		GPIO.setup(i, GPIO.OUT)
		GPIO.setup(i, GPIO.LOW)

def say_hello(name=None):
	if name is None:
		return 'Hello, World!'
	else:
		return f'Hello, {name}!'



from setuptools import setup

with open('README.md', 'r') as f:
	long_description = f.read()

setup(
	name='mygpio',
	version='0.0.2',
	description='GPIO Library which extends GPIO functions',
	long_description=long_description,
	long_description_content_type='text/markdown',
	url='',
	author='Governor Baloyi',
	author_email='governor.baloyi@gmail.com',
	install_requires=[], # list of specifiers
	py_modules=['mygpio'],
	package_dir={'': 'mygpio'},
	extras_require={
		"dev": [
			"pytest>=3.7",
		],
	},
	classifiers=[ 
		# https://pypi.org/classifiers
	],
)